@@ -7,9 +7,10 @@ import re
 import sys
 from collections import deque
 
-from .config import defaults, load_config
 from .conf.utils import resolve_config
+from .config import defaults, load_config
 from .constants import appname, defconf, is_macos, is_wayland, str_version
+from .fast_data_types import GLFW_KEY_UNKNOWN, glfw_get_key_name
 
 CONFIG_HELP = '''\
 Specify a path to the configuration file(s) to use. All configuration files are
@@ -44,7 +45,7 @@ condition=not is_macos
 Set the name part of the :italic:`WM_CLASS` property (defaults to using the value from :option:`{appname} --class`)
 
 
---title
+--title -T
 Set the window title. This will override any title set by the program running inside kitty. So
 only use this if you are running a program that does not set titles.
 
@@ -76,6 +77,12 @@ Path to a file containing the startup :italic:`session` (tabs, windows, layout,
 See the README file for details and an example.
 
 
+--hold
+type=bool-set
+Remain open after child process exits. Note that this only affects the first
+window. You can quit by either using the close window shortcut or :kbd:`Ctrl+d`.
+
+
 --single-instance -1
 type=bool-set
 If specified only a single instance of :italic:`{appname}` will run. New invocations will
@@ -213,6 +220,10 @@ def code(x):
     return x
 
 
+def kbd(x):
+    return x
+
+
 def env(x):
     return italic(x)
 
@@ -614,12 +625,15 @@ def print_shortcut(key_sequence, action):
     keys = []
     for key in key_sequence:
         names = []
-        mods, key = key
+        mods, is_native, key = key
         for name, val in mmap.items():
             if mods & val:
                 names.append(name)
         if key:
-            names.append(krmap[key])
+            if is_native:
+                names.append(glfw_get_key_name(GLFW_KEY_UNKNOWN, key))
+            else:
+                names.append(krmap[key])
         keys.append('+'.join(names))
 
     print('\t', ' > '.join(keys), action)
