@@ -12,7 +12,8 @@ from .boss import Boss
 from .cli import create_opts, parse_args
 from .config import cached_values_for, initial_window_size_func
 from .constants import (
-    appname, config_dir, glfw_path, is_macos, is_wayland, logo_data_file
+    appname, config_dir, glfw_path, is_macos, is_wayland, kitty_exe,
+    logo_data_file
 )
 from .fast_data_types import (
     GLFW_MOD_SUPER, create_os_window, free_font_data, glfw_init,
@@ -69,14 +70,10 @@ def load_all_shaders(semi_transparent=0):
     load_borders_program()
 
 
-def init_graphics(debug_keyboard=False):
+def init_glfw(debug_keyboard=False):
     glfw_module = 'cocoa' if is_macos else ('wayland' if is_wayland else 'x11')
-    if debug_keyboard:
-        os.environ['GLFW_DEBUG_KEYBOARD'] = '1'
-    if not glfw_init(glfw_path(glfw_module)):
+    if not glfw_init(glfw_path(glfw_module), debug_keyboard):
         raise SystemExit('GLFW initialization failed')
-    if debug_keyboard:
-        os.environ.pop('GLFW_DEBUG_KEYBOARD')
     return glfw_module
 
 
@@ -95,7 +92,7 @@ def get_new_os_window_trigger(opts):
             from .fast_data_types import cocoa_set_new_window_trigger
             new_os_window_shortcuts.sort(key=prefer_cmd_shortcuts, reverse=True)
             for candidate in new_os_window_shortcuts:
-                if cocoa_set_new_window_trigger(*candidate):
+                if cocoa_set_new_window_trigger(candidate[0], candidate[2]):
                     new_os_window_trigger = candidate
                     break
     return new_os_window_trigger
@@ -124,7 +121,7 @@ def _run_app(opts, args):
 def run_app(opts, args):
     set_scale(opts.box_drawing_scale)
     set_options(opts, is_wayland, args.debug_gl, args.debug_font_fallback)
-    set_font_family(opts)
+    set_font_family(opts, debug_font_matching=args.debug_font_fallback)
     try:
         _run_app(opts, args)
     finally:
@@ -203,14 +200,8 @@ def _main():
             print('Failed to set locale with no LANG, ignoring', file=sys.stderr)
 
     # Ensure kitty is in PATH
-    rpath = getattr(sys, 'bundle_exe_dir', None)
+    rpath = os.path.dirname(kitty_exe())
     items = frozenset(os.environ['PATH'].split(os.pathsep))
-    if not rpath:
-        for candidate in items:
-            if os.access(os.path.join(candidate, 'kitty'), os.X_OK):
-                break
-        else:
-            rpath = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'launcher')
     if rpath and rpath not in items:
         os.environ['PATH'] += os.pathsep + rpath
 
@@ -227,6 +218,7 @@ def _main():
     args, rest = parse_args(args=args)
     args.args = rest
     if args.debug_config:
+        init_glfw(args.debug_keyboard)  # needed for parsing native keysyms
         create_opts(args, debug_config=True)
         return
     if getattr(args, 'detach', False):
@@ -240,10 +232,10 @@ def _main():
         if not is_first:
             talk_to_instance(args)
             return
+    init_glfw(args.debug_keyboard)  # needed for parsing native keysyms
     opts = create_opts(args)
     if opts.editor != '.':
         os.environ['EDITOR'] = opts.editor
-    init_graphics(args.debug_keyboard)
     try:
         with setup_profiling(args):
             # Avoid needing to launch threads to reap zombies
