@@ -133,6 +133,10 @@ class Window:
             cwd=self.child.current_cwd or self.child.cwd, cmdline=self.child.cmdline
         )
 
+    @property
+    def current_colors(self):
+        return self.screen.color_profile.as_dict()
+
     def matches(self, field, pat):
         if field == 'id':
             return pat.pattern == str(self.id)
@@ -434,7 +438,7 @@ class Window:
             if self.screen.in_bracketed_paste_mode:
                 while True:
                     new_text = text.replace(b'\033[201~', b'').replace(b'\x9b201~', b'')
-                    if text == new_text:
+                    if len(text) == len(new_text):
                         break
                     text = new_text
             self.screen.paste(text)
